@@ -121,16 +121,19 @@ def variations(value,**kwargs):
     typos = objUtils.get_kwarg(['typos'], True, bool, **kwargs)
     case_variations = objUtils.get_kwarg(['case'], True, bool, **kwargs)
     
-    value = str(value)
-    varis = []
-    if typos is True:
-        varis.extend(generate_typos(value))
-    if case_variations is True:
-
-        varis.append(strFormat.to_snake_case(value))
-        varis.append(strFormat.to_screaming_snake(value))
-        varis.extend(strFormat.title_case(varis))
-        varis.extend(strFormat.title_case(varis,True))
+    if isinstance(value,(str)):
+        value = [value]
+        
+    for term in value:
+        # value = str(value)
+        varis = []
+        if typos is True:
+            varis.extend(generate_typos(term))
+        if case_variations is True:
+            varis.append(strFormat.to_snake_case(term))
+            varis.append(strFormat.to_screaming_snake(term))
+            varis.extend(strFormat.title_case(varis))
+            varis.extend(strFormat.title_case(varis,True))
     varis = list(set(varis))
     return varis
 
@@ -264,5 +267,5 @@ def replace_at(s, newstring, index, nofail=False):
 
 
 
-# print(variations("colemen",case=False))
+# print(variations(["colemen","coleman"],case=False))
 # print(missed_key_typos("colemen"))
